#!/bin/bash

cd "$( dirname "${BASH_SOURCE[0]}" )" 

PLUGINNAME="Maximal 3"
PLUGINVERSION="3.0.2"

BOLD='\033[1;33m'
GREEN='\033[0;32m'
RED='\033[0;31m'
NC='\033[0m'


# Show some info
echo -e "\n-------------------"
echo -e "${BOLD}Venomode installer${NC}"
echo -e "-------------------"
echo -e "This will install ${GREEN}$PLUGINNAME VST2${NC} to ${GREEN}~/.vst${NC}"
echo -e "${NC}and/or ${GREEN}$PLUGINNAME VST3${NC} to ${GREEN}~/.vst3${NC}"
echo -e "and the presets and manual to ${GREEN}~/.config/Venomode/$PLUGINNAME${NC}"
echo -e "-------------------"

# Ask and copy the VST2 version
read -p "Would you like to install the VST2 version? (y/n)? " -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
    mkdir -p "$HOME/.vst"
    cp "./VST/$PLUGINNAME.so" "$HOME/.vst/$PLUGINNAME.so"

    if [ $? -ne 0 ]; then 
        echo -e "${RED}Unable to copy the VST2 version${NC}";
    else
        echo -e "  -- Copy successful";
    fi
else
    echo -e "Skipping VST";
fi

# Ask and copy the VST3 version
read -p "Would you like to install the VST3 version? (y/n)? " -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
    # Copy over the VST3
    mkdir -p "$HOME/.vst3/$PLUGINNAME.vst3/Contents/x86_64-linux"
    cp "./VST3/$PLUGINNAME.so" "$HOME/.vst3/$PLUGINNAME.vst3/Contents/x86_64-linux/$PLUGINNAME.so"

    # Earlier versions of this script copied the VST3 binary directly rather 
    # than using the expected VST3 subfolder structure. Some DAWs refused to 
    # load the plugin this way, so we delete it if it's there
    if [ -f "$HOME/.vst3/$PLUGINNAME.so" ]; then
        echo "  -- Removing previous version"
        rm "$HOME/.vst3/$PLUGINNAME.so"
    fi

    if [ $? -ne 0 ]; then 
        echo -e "${RED}Unable to copy the VST3 version${NC}";
    else
        echo -e "  -- Copy successful";
    fi
else
     echo -e "Skipping VST3";
fi

# Copy the presets and manual
mkdir -p "$HOME/.config/Venomode/$PLUGINNAME/Presets/Factory"
cp -R ./Presets/. "$HOME/.config/Venomode/$PLUGINNAME/Presets/Factory/"
if [ $? -ne 0 ]; then 
    echo -e "${RED}Unable to copy the presets${NC}";
else
    echo -e "  -- Presets copied successfully";
fi

cp "./$PLUGINNAME Manual $PLUGINVERSION.pdf" "$HOME/.config/Venomode/$PLUGINNAME/$PLUGINNAME Manual $PLUGINVERSION.pdf"
if [ $? -ne 0 ]; then 
    echo -e "${RED}Unable to copy the manual${NC}";
else
    echo -e "  -- Manual copied successfully";
fi

read -p "Done. Press any key to exit." -n 1 -r
echo